/*
 * SPDX-FileCopyrightText: Stone Tickle <lattis@mochiro.moe>
 * SPDX-License-Identifier: GPL-3.0-only
 */

#ifndef FUNCTIONS_SOURCE_SET_H
#define FUNCTIONS_SOURCE_SET_H
#include "lang/func_lookup.h"

extern const struct func_impl impl_tbl_source_set[];
#endif
